Name:           docker_security
Version:        1.0
Release:        4%{?dist}.fstec
Summary:        Docker security files
License:        GPLv2
URL:            https://msvsphere-os.ru/
BuildArch:      noarch

Source0:        docker_security.tar.gz
# https://github.com/docker/docker-bench-security/releases/tag/v1.6.1
# Взято в полном объеме
# Распространяется под лицензией Apache 2.0
Source1:        docker-bench-security-1.6.1.tar.gz

Requires:       docker-ce
Requires:       docker-ce-cli
Requires:       docker-ce-rootless-extras
Requires:       inotify-tools
Requires:       trivy
Requires:       dockle
Requires:       jq
Requires:       fuse-overlayfs
Requires:       iptables-libs


%description
Docker security files


%prep
%setup -q -n docker_security

tar xf "%{SOURCE1}"


%build
# Nothing to build


%install

# Чтение/запись/запуск для владельца и группы - файл
# defattr(0770,root,root,-)
mkdir -p %{buildroot}/usr/sbin/
for file in scripts/* ; do
    install -m 770 $file %{buildroot}/usr/sbin/
done

# Чтение/запись/запуск для владельца и группы + Чтение/-/запуск для всех - файл
# defattr(0775,root,root,-)
# -
mkdir -p %{buildroot}/etc/sysconfig/modules/
install -m 755 rootfs/etc/sysconfig/modules/iptables.modules %{buildroot}/etc/sysconfig/modules/iptables.modules

# Чтение/запись для владельца и группы - файл
# defattr(0644,root,root,-)
mkdir -p %{buildroot}/usr/lib/systemd/system/
for file in rootfs/usr/lib/systemd/system/* ; do
    install -m 644 $file %{buildroot}/usr/lib/systemd/system/
done

# defattr(0644,root,root,0775)
mkdir -p -m 755 %{buildroot}/etc/docker/
install -m 644 rootfs/etc/docker/daemon.json %{buildroot}/etc/docker/

# 640 простым пользователям смотреть нельзя
# defattr(0640,root,root,-)
mkdir -p %{buildroot}/etc/audit/rules.d/
install -m 640 rootfs/etc/audit/rules.d/docker.rules %{buildroot}/etc/audit/rules.d/

# Все кроме записи для других - каталог
# defattr(0644,root,root,0755)
mkdir -p -m 755 %{buildroot}/etc/docker_security
mkdir -p -m 755 %{buildroot}/etc/docker_security/mail/
mkdir -p -m 755 %{buildroot}/etc/docker_security/integrity/
mkdir -p -m 755 %{buildroot}/etc/docker_security/rootless-config/
# 640 простым пользователям смотреть нельзя
install -m 640 rootfs/etc/docker_security/integrity/integrity.list %{buildroot}/etc/docker_security/integrity/
install -m 640 rootfs/etc/docker_security/mail/send_mail_settings.json %{buildroot}/etc/docker_security/mail/
# 644 простым пользователям смотреть можно
install -m 644 rootfs/etc/docker_security/rootless-config/daemon.json %{buildroot}/etc/docker_security/rootless-config/

# docker-bench-security
mkdir -p -m 755 %{buildroot}/opt/docker-bench-security/
cp -a docker-bench-security-1.6.1/* %{buildroot}/opt/docker-bench-security/

mkdir -p -m 755 %{buildroot}/etc/skel/.config/docker/

%clean
rm -rf %{buildroot}


%files

%defattr(0770,root,root,-)
/usr/sbin/docker_s
/usr/sbin/docker_s_functions
/usr/sbin/docker_s_home_monitor.sh
/usr/sbin/docker_s_scan_login.sh
/usr/sbin/docker_s_scan_login_delay.sh
/usr/sbin/docker_s_scan_time.sh
/usr/sbin/docker_s_scanners.sh
/usr/sbin/docker_s_send_mail.sh
/usr/sbin/docker_s_send_not_send_files.sh
/usr/sbin/docker_s_tracker.sh
/usr/sbin/docker_s_tracker_monitor.sh
/usr/sbin/docker_s_users.sh
/usr/sbin/docker_n_watchdog_routine.sh
/usr/sbin/docker_n_watchdog_wrapper.sh
/usr/sbin/docker_n_email_notification_tool.sh
/usr/sbin/docker_n_integrity

%defattr(0775,root,root,-)
/etc/sysconfig/modules/iptables.modules

%defattr(0644,root,root,-)
/usr/lib/systemd/system/docker_monitor.service
/usr/lib/systemd/system/docker_scan_login.service
/usr/lib/systemd/system/docker_scan_time.service
/usr/lib/systemd/system/docker_scan_time.timer
/usr/lib/systemd/system/docker_tracker.service
/usr/lib/systemd/system/docker_watchdog.service
/usr/lib/systemd/system/docker_integrity.service

%defattr(0644,root,root,0755)
/etc/docker/daemon.json

%defattr(0640,root,root,-)
/etc/audit/rules.d/docker.rules

%defattr(0640,root,root,0755)
/etc/docker_security/integrity/integrity.list

%defattr(0640,root,root,0755)
/etc/docker_security/mail/send_mail_settings.json

%defattr(0644,root,root,0755)
/etc/docker_security/rootless-config/daemon.json

%defattr(-,root,root,-)
/opt/docker-bench-security/*

%defattr(-,root,root,-)
/etc/skel/.config/docker/


%post
# Выполним после установки пакета

# Если общесистемный демон Docker запущен, то использовать Docker в rootless mode не получится
# Отключим службу Docker и сокет, чтобы можно было настроить работу Docker без прав суперпользователя
systemctl disable --now docker.service docker.socket

rm -f /var/run/docker.sock

# Это может потребоваться для решения проблем с сетью
modprobe ip_tables

# для аудита добавили новые правила. Перезапустим
augenrules --load > /dev/null 2>&1 || true

# обновим конфигурации и перезапустим демон systemd
systemctl daemon-reload

# Настроим переменную среды, которая включает механизм DOCKER CONTENT TRUST (DCT).
# DCT - это механизм цифровой подписи и проверки образов, которые выгружаются из реестров Docker.
# Он позволяет убедиться, что загружаемые образы пришли от предполагаемого издателя (аутентичность)
# и не были изменены злоумышленниками (целостность).

grep -q "DOCKER_CONTENT_TRUST=1" /etc/environment &> /dev/null || echo "DOCKER_CONTENT_TRUST=1" >> /etc/environment

# Сделаем исполняемыми
chmod 755 /opt/docker-bench-security/docker-bench-security.sh
# Сделаем защищенным
# chattr +i /etc/docker_security/rootless-config/daemon.json


%preun
# Выполним после удаления пакета
systemctl stop docker_monitor.service
systemctl stop docker_scan_login.service
systemctl stop docker_scan_time.service
systemctl stop docker_scan_time.timer
systemctl stop docker_tracker.service
systemctl stop docker_watchdog.service
systemctl stop docker_integrity.service

%postun
augenrules --load > /dev/null 2>&1 || true


%changelog
* Wed Feb 19 2025 Arkady L. Shane <tigro@msvsphere-os.ru> - 1.0-4.fstec
- Fix loading rules to audit

* Fri Feb 14 2025 Arkady L. Shane <tigro@msvsphere-os.ru> - 1.0-3
- Rebuilt for MSVSphere 9.5

* Fri Feb 07 2025 LLC "NCSD" MSVSphere 9.5 - 1.0-3
- Build for MSVSphere 9.5
- release
- Additional output to syslog

* Thu Feb 06 2025 LLC "NCSD" MSVSphere 9.5 - 1.0-2.xx
- Build for MSVSphere 9.5
- Debugging and bug fixing
- Add supports scans: trivy, bench
- Add supports scans: dockle
- Add docker_s -s option
- Add recipient_copy

* Sun Jan 26 2025 LLC "NCSD" MSVSphere 9.5 - 1.0-2
- Build for MSVSphere 9.5
- Use docker-bench-security-1.6.1 from https://github.com/docker/docker-bench-security/releases/tag/v1.6.1
- Fix bug in test 4.5. Repack.

* Sun Jan 26 2025 LLC "NCSD" MSVSphere 9.5 - 1.0-1
- Build for MSVSphere 9.5
